@@ -3,6 +3,7 @@ extern crate lazy_static;
 
 pub mod ast;
 pub mod error_handling;
+pub mod runtime;
 pub mod lexer {
     pub mod lex;
 }
@@ -35,3 +36,7 @@ pub mod wasm {
     mod utils;
     pub mod wasm_exports;
 }
+
+pub mod static_checking {
+    pub mod exhaustiveness;
+}
