@@ -1,8 +1,14 @@
 mv Cargo.toml Cargo.desktop.toml
 mv Cargo.wasm.toml Cargo.toml
-~/.cargo/bin/wasm-pack build
+
+wasm-pack build
+
+rm -r skiff-lang
+mv pkg skiff-lang
+
 mv Cargo.toml Cargo.wasm.toml
 mv Cargo.desktop.toml Cargo.toml
 echo ""
 echo "Package built"
-echo "Remember to update name, version, and add snippets directory"
\ No newline at end of file
+echo "Remember to add snippets directory"
+echo "'wasm-pack publish' to publish"
